######################################################################################
# ADTec Moia Tool: Moia_para                                                         #
#       Load or Unload data from oracle database.                                    #
######################################################################################

BANNERLINE="============================================================"
DATA_PATH="./tempdata"
logdir=.
loadlog=$logdir/load.log
unloadlog=$logdir/unload.log


echo_machine()
{
    if [ "`echo -n ''`" = "" ]
    then
        MINUSN="-n"
        SLASHC=""
    else
        MINUSN=""
        SLASHC='\c'
    fi
}

echo_version_info()
{
    if [ "X$LOADMODE" = "Xload" ] 
    then
        echo "    $BANNERLINE "    
        echo "                      --- ADT Moia Tool ---"
        echo "          Moia_para V1.0: Load data to oracle database!"
        echo "    $BANNERLINE "    
    else
        echo "    $BANNERLINE "    
        echo "                      --- ADT Moia Tool ---"
        echo "          Moia_para V1.0: Unload data from oracle database!"
        echo "    $BANNERLINE"    
    fi

    echo "        Notice: Before run the Moia_para, you must be sure that 
    oracle database user is created, and the tables you want to 
    load or unload are created!"
    echo ""
}

get_db_info()
{
    unset CONNTYPE
    unset DBTYPE

    echo $MINUSN "        Specify the database type; [1:oracle|2:DB2]: " $SLASHC
    read answer
    while [ "$answer" != "1" ] && [ "$answer" != "2" ]
    do
        echo ""
        echo "        <!> You must choose the database type: 1 or 2 ."
        echo $MINUSN "        Specify the database type; [1:oracle|2:DB2]: " $SLASHC
        read answer
    done
    DBTYPE=$answer

    echo $MINUSN "        Specify the database connect type; [1:local|2:remote]: " $SLASHC
    read answer
    while [ "$answer" != "1" ] && [ "$answer" != "2" ]
    do
        echo ""
        echo "        <!> You must choose the database connect type: 1 or 2 ."
        echo $MINUSN "        Specify the database connect type; [1:local|2:remote]: " $SLASHC
        read answer
    done

    case $answer in
        1)
            CONNTYPE="LOCAL_CONNECT"
            ;;
        2)
            CONNTYPE="NET_CONNECT"
            ;;
    esac

}

get_ora_login()
{
    unset USERID
    unset PASSWD
    unset SRVNAME

    echo ""
    echo $MINUSN "        Specify the oracle database username: " $SLASHC
    read answer
    while [ "X$answer" = "X" ]
    do
        echo $MINUSN "        Specify the oracle database username: " $SLASHC
        read answer
    done
    USERID=$answer
        
    echo $MINUSN "        Specify the oracle database password: " $SLASHC
    read answer
    while [ "X$answer" = "X" ]
    do
        echo $MINUSN "        Specify the oracle database password: " $SLASHC
        read answer
    done
    PASSWD=$answer

    if [ "X$CONNTYPE" = "XNET_CONNECT" ]
    then
        echo $MINUSN "        Specify the oracle database service name: " $SLASHC
        read answer
        while [ "X$answer" = "X" ]
        do
            echo $MINUSN "        Specify the oracle database service name: " $SLASHC
            read answer
        done
        SRVNAME=$answer
    fi

}

#ݿ
test_ora_conn()
{
    unset IFSUCC
    unset ORACONN

    if [ "X$CONNTYPE" = "XNET_CONNECT" ]
    then
        ORACONN=$USERID/$PASSWD@$SRVNAME
    else
        ORACONN=$USERID/$PASSWD
    fi

IFSUCC=`sqlplus $ORACONN <<EOF | grep ^[0-9]| cut -d. -f1
    select to_char(sysdate, 'YYYY-MM-DD HH24:MI:SS') from dual;
EOF`
    return_code="0"
    if [ "X$IFSUCC" = "X" ]
    then
        return_code="1"
    fi
}

#ָļ
specify_cfg_file()
{
    echo ""
    echo $MINUSN "        Specify the configuration filename: " $SLASHC
    read answer
   
    while [ "X$answer" = "X" ]
    do
        echo $MINUSN "        Specify the configuration filename: " $SLASHC
        read answer
    done

    return_code="0"
    if [ ! -f $answer ]
    then 
        return_code="1"
    fi

    CFG_FILE=$answer
}

#װ,ָԴļ·,ж,ָݴ·
specify_data_path()
{
    echo ""
 
    return_code="0"
    if [ "X$LOADMODE" = "Xload" ]
    then
        echo $MINUSN "        Specify the directory of data source: " $SLASHC
        read answer

        if [ "X$answer" = "X" ] || [ ! -d $answer ]
        then
            return_code="1"
            return $return_code
        fi

        DATA_PATH=$answer
        return $return_code
    fi

    echo $MINUSN "        Specify the directory of data storage or press <enter> 
        default <$DATA_PATH>: " $SLASHC
    read answer

    if [ "X$answer" != "X" ] && [ ! -d $answer ]
    then
        mkdir -p $answer
        if [ $? != 0 ]; then
            return_code="1"
        fi
        DATA_PATH=$answer
        return 1
    elif [ "X$answer" = "X" ] 
    then
        mkdir -p $DATA_PATH
        if [ $? != 0 ]; then
            return_code="1"
        fi
        return 1
    fi

    DATA_PATH=$answer
}

#
specify_table_name()
{
    unset TABLE_LIST
    unset IFSUCC

    echo ""
    echo $MINUSN "        Specify the table name,if you have more talbes,use
        <space> to separate them: "  $SLASHC
    read answer

    return_code="0"
    if [ "X$answer" = "X" ]
    then
        echo $MINUSN "        Specify the table name,if you have more talbes,use
        <space> to separate them: "  $SLASHC
        read answer

        return_code="1"
        return $return_code
    fi
   
    return_code="0"
    for onetab in $answer
    do
IFSUCC=`sqlplus $ORAUSERID <<EOF | grep "ORA-00942:"
    select * from ${onetab};
EOF`
        if [ "X$IFSUCC" != "X" ]
        then 
            echo "        <!> [$onetab]: Table or view you input does not exist!"
            return_code="1"
            return $return_code
        fi
    done

    TABLE_LIST=$answer
}

#ѡ¼뷽ʽ, ж,Ҫļֹ
select_input_type()
{
    echo ""
    echo $MINUSN "        Specify the table name, select the input type
        [1:file name|2:tables name|3:all user tables]: " $SLASHC
    read answer

    while [ "$answer" != "1" ] && [ "$answer" != "2" ] && [ "$answer" != "3" ]
    do
        echo ""
        echo "        <!> You can only select input type: 1 or 2 or 3."
        echo $MINUSN "        Specify the table name, select the input type
        [1:file name|2:tables name|3:all tables]: " $SLASHC
        read answer
    done

    case $answer in
        1)
            input_type="FILE_TYPE" 
            ;;
        2)
            input_type="TAB_TYPE" 
            ;;
        3)  input_type="ALL_TABLE"
            ;;
    esac
}

# ݿӼ
conn_err_proc()
{
    loop=1
    while [ "$return_code" -ne 0 ]
    do
        echo "        <!> Connect error, maybe incorrect login infomation!"   

        loop=`expr $loop + 1`
        if [ $loop -gt 3 ]
        then
            echo "        <!> Connect error three times, contact database administrator!"
            return_code="-1"
            return $return_code
        fi

        get_ora_login 
        test_ora_conn
    done
}

# ļڼ
file_err_proc()
{
    loop=1
    while [ "$return_code" -ne 0 ]
    do
        echo "        <!> The configuration filename you specified does not exist!"
        loop=`expr $loop + 1`
        if [ $loop -gt 3 ]
        then
            echo "        <!> Error three times,please check it and try again!"
            return_code="-1"
            return $return_code
        fi

        specify_cfg_file
    done
}

# ڼ
table_err_proc()
{
    loop=1
    while [ "$return_code" -ne 0 ]
    do
        loop=`expr $loop + 1`
        if [ $loop -gt 3 ]
        then
            return_code="-1"
            return $return_code
        fi

        specify_table_name
    done
}

# Ŀ¼ڼ
path_err_proc()
{
    loop=1
    while [ "$return_code" -ne 0 ]
    do
        echo "        <!> The data resource path that you specified does not exist!"
        loop=`expr $loop + 1`
        if [ $loop -gt 3 ]
        then
            echo "        <!> Error three times,please check it and try again!"
            return_code="-1"
            return $return_code
        fi

        specify_data_path
    done
}

#ͳݵĵ뵼
data_statistic()
{
    if [ "X$LOADMODE" = "Xload" ]
    then
        TOTAL=`awk '{ print $0 }' $loadlog |wc -l`
        SUCCESS=`awk '{ print $0 }' $loadlog | grep SUCCESS | wc -l`
        WARNING=`awk '{ print $0 }' $loadlog | grep WARNING | wc -l`
        ABNORMAL=`awk '{ print $0 }' $loadlog | grep ABNORMAL | wc -l`
        ERROR=`awk '{ print $0 }' $loadlog | grep ERROR | wc -l`
        echo "        Total   :[$TOTAL]" |tee -a $loadlog                
        echo "        Success :[$SUCCESS]" |tee -a $loadlog                
        echo "        Warning :[$WARNING]"  |tee -a $loadlog                
        echo "        Abnormal:[$ABNORMAL]" |tee -a $loadlog                
        echo "        Error   :[$ERROR]" |tee -a $loadlog                
        echo "        Recorded in the log file:[$loadlog]." |tee -a $loadlog                
    else
        TOTAL=`awk '{ print $0 }' $unloadlog |wc -l`
        SUCCESS=`awk '{ print $0 }' $unloadlog | grep SUCCESS | wc -l`
        ABNORMAL=`awk '{ print $0 }' $unloadlog | grep ABNORMAL | wc -l`
        ERROR=`awk '{ print $0 }' $unloadlog | grep ERROR | wc -l`
        echo "        Total   :[$TOTAL]"  #|tee -a $unloadlog                
        echo "        Success :[$SUCCESS]" #|tee -a $unloadlog                
        echo "        Abnormal:[$ABNORMAL]" #|tee -a $unloadlog                
        echo "        Error   :[$ERROR]" #|tee -a $unloadlog                
        echo "        Recorded in the log file:[$unloadlog]." #|tee -a $unloadlog                
    fi
}

#ʵװ
data_load()
{
    echo $MINUSN $SLASHC > $loadlog
   
    if [ "X$input_type" = "XFILE_TYPE" ]
    then
        for onetab in `cat $CFG_FILE`
        do
            MParaLoad $ORACONN $DATA_PATH/$onetab.txt $onetab $DATA_LOAD | tee -a $loadlog     
        done
  
        return 1
    elif [ "X$input_type" = "XALL_TABLE" ]
    then
        for onerecord in `ls $DATA_PATH/*.txt`
        do
            onetab=`echo ${onerecord##*/} | awk -F "." '{ print $1 }'`
            MParaLoad $ORACONN $DATA_PATH/$onetab.txt $onetab $DATA_LOAD | tee -a $loadlog     
        done

    else
        for onetab in $TABLE_LIST
        do
            if `ls $DATA_PATH/$onetab.txt > /dev/null 2>&1`
            then
                MParaLoad $ORACONN $DATA_PATH/$onetab.txt $onetab $DATA_LOAD | tee -a $loadlog     
            else
                echo "        <!> [$onetab]: Table does not exist in [$DATA_PATH]!" | tee -a $loadlog     
            fi
        done
    fi
}

#ʵж
data_unload()
{
    echo $MINUSN $SLASHC > $unloadlog

    if [ "X$input_type" = "XFILE_TYPE" ]
    then
        for onetab in `cat $CFG_FILE`
        do
            MParaUnl $ORACONN $DATA_PATH/$onetab.txt $onetab |tee -a $unloadlog          
        done
    elif [ "X$input_type" = "XALL_TABLE" ]
    then
labstr=Ffengligang
ALLTABLES=`sqlplus $ORACONN <<EOF | grep ${labstr} | awk -F" " '{print $2 }' | tr "[A-Z]" "[a-z]"
select '${labstr}', table_name from user_tables;
EOF`
        for onetab in $ALLTABLES
        do
            MParaUnl $ORACONN $DATA_PATH/$onetab.txt $onetab | tee -a $unloadlog         
        done
    else
        for onetab in $TABLE_LIST 
        do
            MParaUnl $ORACONN $DATA_PATH/$onetab.txt $onetab |tee -a $unloadlog          
        done
    fi
}

select_data_load()
{
    echo
    echo $MINUSN "        Specify the data load mode [1:Append|2:Replace]: " $SLASHC       
    read answer

    while [ "$answer" != "1" ] && [ "$answer" != "2" ] 
    do
        echo ""
        echo "        <!> You must select data load mode: 1 or 2 !"
        echo $MINUSN "        Specify the data load mode [1:Append|2:Replace]: " $SLASHC       
        read answer
    done

    DATA_LOAD=$answer

    echo
    echo $MINUSN "        Notice: You will load the data to [$ORACONN],
        Are you sure to continue? [y:yes|n:no]: " $SLASHC
        read answer

    while [ "$answer" != "y" ] && [ "$answer" != "n" ] && \
          [ "$answer" != "Y" ] && [ "$answer" != "N" ]
    do
        echo ""
        echo $MINUSN "        <!> You must choose the y or n. Are you sure?
        [y:yes|n:no]:" $SLASHC
        read answer
    done
 
    ISURE=$answer
}

prep_main()
{
    ret_status="0"

    echo_machine
    echo_version_info

    get_db_info
    get_ora_login

    test_ora_conn
    conn_err_proc
    if [ $return_code -eq -1 ]
    then
        ret_status="quit"
        return 1
    fi

    specify_data_path
    path_err_proc
    if [ $return_code -eq -1 ]
    then
        ret_status="quit"
        return 1
    fi

    select_input_type
    if [ "X$input_type" = "XFILE_TYPE" ]
    then
        specify_cfg_file
        file_err_proc
        if [ $return_code -eq -1 ]
        then
            ret_status="quit"
            return 1
        fi
    elif [ "X$input_type" = "XTAB_TYPE" ]
    then
        specify_table_name
        table_err_proc
        if [ $return_code -eq -1 ]
        then
            ret_status="quit"
            return 1
        fi
    fi
}

##########################################################################
# main                                                                   #
##########################################################################

    if [ "X$1" != "Xload" ] && [ "X$1" != "Xunload" ] || [ "X$1" = "X" ]
    then
        echo "    Usage: $0 <OPTION>"
        echo "       <OPTION> "
        echo "          load:   Load data to oracle database!"
        echo "        unload:   Unload data from oracle database!"
        echo ""
        exit 1
    fi

    case $1 in
        load)
            LOADMODE=load
            ;;
        unload)
            LOADMODE=unload
            ;;
        *)
            exit 1
            ;;
    esac

    prep_main
    if [ "X$ret_status" = "Xquit" ]
    then
        exit 1
    fi

    if [ "X$LOADMODE" = "Xunload" ]
    then
        echo " "
        echo "        --------- Data Unload begin! ----------"        
        echo " "
        data_unload
        echo " "
        data_statistic
        echo "        -------- Data Unload complete! --------"
    else
        select_data_load
        if [ "X$ISURE" = "Xn" ] || [ "X$ISURE" = "XN" ]
        then
            echo
            echo "        -------- Exit -------"
            exit 1
        fi

        echo " "
        echo "        --------- Data Load begin! ----------"        
        echo " "
        data_load
        echo " "
        data_statistic
        echo "        -------- Data Load complete! --------"
    fi


