#!/bin/sh
###############################################################################
#
# Install.sh
#
# Set variables, check install requirements
# and runs the compiled setup program
#
##############################################################################
#
# Maintenence log - insert most recent change descriptions at top
#
# Date......   Version  Description...........................................
# 2015/06/30   5.02     Moia Control Develop
##############################################################################

umask 0022
#export LANG=zh_CN
export MOIADIR=`pwd`

unique=`date '+%Y%m%d.%H%M%S'`
instlog="$MOIADIR/MoiaControlInstall.log.$unique"



##########################################################################
#
##########################################################################
inst_make_env()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Create executable programs ..." | tee -a $instlog
    echo | tee -a $instlog

    # default 64 bit
    object_modE=64

OS=`uname -s|sed -e 's/-//g'`
case $OS in
"HPUX")
        OSVER=11
        if test `getconf KERNEL_BITS` != "64" ;then
            OBJECT_MODE=32
        else
            OBJECT_MODE=64
        fi
        if [ "`uname -m`" = "ia64" ]
        then
            SHLIB="LD_LIBRARY_PATH"
        else
            SHLIB="SHLIB_PATH"
        fi
        ;;
"Linux")
        if test `uname -m` = "x86_64" ;then
            OBJECT_MODE=64
        else
            OBJECT_MODE=32
        fi
        OSVER=`lsb_release -r|cut -d: -f2|sed -e 's/^[[:space:]]*//'|cut -d. -f1`
        if [ "X$OSVER" = "X" ];then
            OSVER=`cat /etc/os-release|grep ^VERSION=|tr -cd "[0-9]"`
        fi 
        SHLIB="LD_LIBRARY_PATH"
        ;;
"AIX")
        #if test `bootinfo -K` != "64" ;then
        #    OBJECT_MODE=32
        #else
        #    OBJECT_MODE=64
        #fi
        OBJECT_MODE=64
        OSVER=`oslevel|cut -d"." -f1`
        SHLIB="LIBPATH"
        PATH=/usr/vacpp/bin:$PATH
        ;;
"SunOS")
        if test `isainfo -bv` = "64" ;then
            OBJECT_MODE=64
        else
            OBJECT_MODE=32
        fi
        OSVER=`showrev|grep "Release"|cut -d"." -f2 `
        SHLIB="LD_LIBRARY_PATH"
        ;;
*)
        echo "     ERROR: MOIA not support this system: [$OS]" | tee -a $instlog
        return 1
esac

export OS
export OSVER
export SHLIB
export OBJECT_MODE

PATH=$MOIADIR/bin:$MOIADIR/sbin:.:$PATH
export PATH

#DBDBVER
export DBTYPE=N
export DBVER=0

ETLTYPE=NONE
if [ "X$DSHOME" != "X" ]
then
    export ETLTYPE=DATASTAGE
    export DSHOME
    if [ ! -f $MOIADIR/env/DataStage.env ]
    then
        echo "     ERROR: $MOIADIR/env/DataStage.env not exist!!!" | tee -a $instlog
        return 1
    else
        . $MOIADIR/env/DataStage.env
    fi

fi


sh $MOIADIR/sbin/mcheck 2 | tee -a $instlog
if test $? -ne 0;then
echo "     Error: Moia check envirment failed!" | tee -a $instlog
return 1
fi


### make all programs ###

make_agent

# get MOIA_RELEASE file

echo "MOIAVER=5.0
MOIA_BLD=`date +%Y%m%d%H%M%S`
OS=$OS
OSVER=$OSVER
OBJECT_MODE=$OBJECT_MODE
DBTYPE=NULL
DBVER=0
ETLTYPE=$ETLTYPE
ETLVER=$ETLVER" > $MOIADIR/etc/MOIA_RELEASE

}

make_agent()
{

echo "make agent files ..."

cd $MOIADIR/.src

make public 
#>>$instlog 2>&1
if test $? -ne 0;then
    echo "     ERROR: make source file failed!" | tee -a $instlog
    exit 1
fi

make agent 
#>>$instlog 2>&1
if test $? -ne 0;then
    echo "     ERROR: make source file failed!" | tee -a $instlog
    exit 1
fi

cd $MOIADIR/src/link
make agt 
# >>$instlog 2>&1
if test $? -ne 0;then
    echo "     ERROR: link programs failed!" | tee -a $instlog
    exit 1
fi

}

##########################################################################
retry_info()
{
    while [ 1 = 1 ]
    do
        echo $MINUSN "Q - Quit; R or < cr > to retry: " $SLASHC
        read answer
        if [ "X${answer}" = "XQ" ]
        then
            do_exit
        fi
        if [ "X${answer}" = "X" -o "X${answer}" = "XR" ]
        then
            echo
            break
        fi
    done

}

##########################################################################
# echo_machine - Handles surpressing of automatic newlines when echoing  #
##########################################################################
echo_machine()
{
    if [ "`echo -n ''`" = "" ]
    then
        MINUSN="-n"
        SLASHC=""
    else
        MINUSN=""
        SLASHC='\c'
    fi
}


##########################################################################
#  continue_info  - Notes the user to choose whether to continue or quit #
##########################################################################
continue_info()
{
    while [ 1 = 1 ]
    do
        echo
        echo $MINUSN "Q - Quit; C or < cr > to continue: " $SLASHC
        read answer
        if [ "X${answer}" = "XQ" ]
        then
            exit
        fi
        if [ "X${answer}" = "X" -o "X${answer}" = "XC" ]
        then
            echo
            break
        fi
    done
}

##########################################################################
# wait_screen - Handles waiting for operations to complete               #
##########################################################################
wait_screen()
{
    look_for=$1
    called_from=$2

    echo $MINUSN "     " $SLASHC
    sleep 1

    cr=0;
    kill -0 $! 2>/dev/null
    while [ "$?" = 0 ]
    do
        sleep 1
        if [ $cr -eq 65 ]
        then
            echo ""
            echo $MINUSN "     " $SLASHC
            cr=0
        fi

        echo $MINUSN "*" $SLASHC

        cr=`expr $cr + 1`
        kill -0 $! 2>/dev/null
    done

}

##########################################################################
# clear_screen - Handles clearing the screen and displaying the title    #
##########################################################################
clear_screen()
{
    clear

    echo
    echo "[ Moia Control - Installation and Maintenance Utility ]"
    echo
    echo
}

##########################################################################
# check_platform - Handles check the platform is avaluable for moia      #
##########################################################################
check_platform()
{

    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Check system environment information ..." | tee -a $instlog
    echo | tee -a $instlog

OS=`uname -s|sed -e 's/-//g'`

if test X$OS != X$OS_IN;then
    echo ""
    echo "     ERROR:Your product package for ${OS_IN}, but your system is ${OS} " | tee -a $instlog
    exit 1
fi

os_host_name=`hostname`
case $OS in
"HPUX")
        OSVER=11
        if test `getconf KERNEL_BITS` = "64" ;then
            OSMODE=64
        else
            OSMODE=32
        fi
        if test `uname -m` = "ia64";then
            SHLIB="LD_LIBRARY_PATH"
        else
            SHLIB="SHLIB_PATH"
        fi
        os_hostip=`netstat -in | awk ' { if (NR==2) print $4 } '`

        vmstat 1 1 > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "     ERROR:Lack of vmstat authority! " | tee -a $instlog
            do_exit
        fi
        machinfo > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "     ERROR:Lack of machinfo authority! " | tee -a $instlog
            do_exit
        fi
        netstat -in > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "     ERROR:Lack of netstat authority! " | tee -a $instlog
            do_exit
        fi
        ;;
"Linux")
        if test `uname -m` = "x86_64" ;then
            OSMODE=64
        else
            OSMODE=32
        fi
        OSVER=`lsb_release -r|cut -d: -f2|sed -e 's/^[[:space:]]*//'|cut -d. -f1`
        if [ "X$OSVER" = "X" ];then
            OSVER=`cat /etc/os-release|grep ^VERSION=|tr -cd "[0-9]"`
        fi 
        SHLIB="LD_LIBRARY_PATH"
        #os_hostip=`ping -c 1 ${os_host_name} | head -1 | cut -d'(' -f2|cut -d')' -f1`
        os_hostip=`hostname -i`

        sar 1 1 > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
           echo "     ERROR:Lack of sar authority! " | tee -a $instlog
           exit 1
        fi
        dmesg > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
           echo "     ERROR:Lack of dmesg authority! " | tee -a $instlog
           exit 1
        fi
        ;;
"AIX")
        #if test `bootinfo -K` = "64" ;then
        #    OSMODE=64
        #else
        #    OSMODE=32
        #fi
        OSMODE=64
        OSVER=`oslevel|cut -d"." -f1`
        SHLIB="LIBPATH"
        #os_hostip=`ping -c 1 ${os_host_name} | head -1 | cut -d'(' -f2|cut -d')' -f1`
        os_hostip=`hostname -i`

        vmstat 1 1 > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "     ERROR:Lack of vmstat authority! " | tee -a $instlog
            exit 1
        fi
        ;;
"SunOS")
        if test `isainfo -bv` = "64" ;then
            OSMODE=64
        else
            OSMODE=32
        fi
        OSVER=`showrev|grep "Release"|cut -d"." -f2 `
        SHLIB="LD_LIBRARY_PATH"
        #os_hostip=`ping -c 1 ${os_host_name} | head -1 | cut -d'(' -f2|cut -d')' -f1`
        os_hostip=`hostname -i`

        vmstat 1 1 > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "     ERROR:Lack of vmstat authority! " | tee -a $instlog
            exit 1
        fi
        netstat -in > /dev/null 2>&1
        if [ $? -ne 0 ]
        then
            echo "     ERROR:Lack of netstat authority! " | tee -a $instlog
            exit 1
        fi
        ;;
*)
        echo "     ERROR: MOIA not support this system: $OS!" | tee -a $instlog
        exit 1
esac

if test "X$IPADDR" != "X";then
    os_hostip=$IPADDR
fi

if test X$OS != X$OS_IN;then
    echo ""
    echo "     ERROR: You product package for ${OS_IN}, but your system is ${OS}!" | tee -a $instlog
    exit
fi

#if test X$OSVER != X$OSVER_IN;then
#    echo ""
#    echo "     WARNING: You product package for ${OS_IN}${OSVER_IN}, but your system is ${OS}${OSVER}!" | tee -a $instlog
#    continue_info
#fi

if test X$OSMODE = "X32" ;then
    if test "X$OBJMODE_IN" = "X64" ;then
        echo ""
        echo "     ERROR: system OS is ${OSMODE}-bit, not suport ${OBJMODE_IN}-bit!" | tee -a $instlog
        exit 1
    fi
else
    if test X$OBJMODE_IN = "X32" ;then
        echo ""
        echo "     WARNING: system OS is ${OSMODE}-bit,product package is ${OBJMODE_IN}-bit!" | tee -a $instlog
        continue_info
    fi
fi

    SHPATH=$MOIADIR/lib:$MOIADIR/lib/other
    eval ${SHLIB}=\$${SHLIB}:${SHPATH}
    export ${SHLIB}

}

check_etl_env()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Check DataStage environment infomation ..." | tee -a $instlog
    echo | tee -a $instlog
    
if test X$DSHOME != "X";then
    . $MOIADIR/env/DataStage.env >> $instlog
    if test $? -ne 0;then 
        echo ""
        echo "     ERROR: $DSHOME set incorrect!" | tee -a $instlog
        exit 1
    fi
fi

}


db2_bnd_file()
{
    if test X$DBTYPE_IN != "XDB2"
    then
        return 0
    fi
    if test X$SERVER_NODE != "XN"
    then
        return 0
    fi

    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     DB2 Binding files, please wait ..."  | tee -a $instlog
    echo | tee -a $instlog

    if test ! -f "${MOIADIR}/sbin/DB2_BND.sh"
    then
        echo "     ERROR: ${MOIADIR}/sbin/DB2_BND.sh not exist!" | tee -a $instlog
        exit 1
    fi
    type stdbuf
    if test $? -ne 0
    then 
        ${MOIADIR}/sbin/DB2_BND.sh >> $instlog 
    else
        ${MOIADIR}/sbin/DB2_BND.sh | tee -a $instlog |stdbuf -oL grep "LINE"| sed -e "s/.* FOR/ bind  /g"
    fi
}

check_db_env()
{

    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Check database environment infomation ..." | tee -a $instlog
    echo | tee -a $instlog

if test X$DBTYPE_IN = "XORACLE";then
#    . $MOIADIR/env/ORACLE.env
CONNMSG=`sqlplus -S ${ORAUSERID} << EOF  >> $instlog 2>&1
WHENEVER SQLERROR EXIT SQL.SQLCODE
select distinct(version) from product_component_version;
quit;
EOF`

    if test $? -ne 0
    then
        echo "     ERROR: Test ORACLE connect to ${ORAUSERID} failed!" | tee -a $instlog
        exit 1
    fi

#    DBVER=`echo ${CONNMSG}| sed -e 's/\..*//g'`
    DBVER=`sqlplus -V| sed -e 's/.*Release //g' -e 's/\..*//g' -e '/^$/d'`
    if test X$DBVER != X$DBVER_IN;then
        echo "     WARNING: You product package released on oracle version [$DBTYPE_IN$DBVER_IN}]." | tee -a $instlog
        #continue_info
        unlink $MOIADIR/lib/other/libclntsh.so.${DBVER_IN}.1
        ln -sf $ORACLE_HOME/lib/libclntsh.so $MOIADIR/lib/other/libclntsh.so.${DBVER_IN}.1
    fi
else
#    . $MOIADIR/env/DB2.env
    db2 connect to ${DB2USERID} >>$instlog 2>&1
    if test $? -ne 0
    then
        echo "     ERROR: test DB2 connect to ${DB2USERID} failed!" | tee -a $instlog
        exit 1
    fi
    DBVER=`db2licm -v| sed -e 's/\..*//g'`
    #if test X$DBVER != X$DBVER_IN;then
    #    echo "     WARNING: You product package of ${PRODUCT}${MOIAVER} only support [$DBTYPE$DBVER_IN}]."  | tee -a $instlog
    #    continue_info
    #fi
fi

}

##########################################################################
# install_moia_env - Handles install moia env ,create moia.env #
##########################################################################
install_srv_env()
{
    # Copy moia environment file
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Create server environment file ..." | tee -a $instlog
    echo | tee -a $instlog


    file=$MOIADIR/env/moia.env
    echo "#--------------------- MOIA PUBLIC BEGIN -----------------------# " >$file
    echo "MOIADIR=$MOIADIR" >> $file
    echo "export MOIADIR"  >> $file
    echo ""  >> $file
    echo "MOIAVER=$MOIAVER"  >> $file
    echo "export MOIAVER"  >> $file
    echo ""  >> $file
    echo "OBJECT_MODE=$OBJMODE_IN"  >> $file
    echo "export OBJECT_MODE"  >> $file
    echo ""  >> $file
    echo "INSTMODE=SRV"  >> $file
    echo "export INSTMODE"  >> $file
    echo ""  >> $file
    echo "DBTYPE=$DBTYPE_IN"  >> $file
    echo "export DBTYPE"  >> $file
    echo ""  >> $file
if test X$DBTYPE_IN = "XORACLE";then
    echo "ORACLE_HOME=$ORACLE_HOME"  >> $file
    echo "export ORACLE_HOME"  >> $file
else
    echo "INSTHOME=$INSTHOME"  >> $file
    echo "export INSTHOME"  >> $file
fi
    echo ""  >> $file
    echo "MOIA_DBS=$MOIA_DBS"  >> $file
    echo "export MOIA_DBS"  >> $file
    echo ""  >> $file
    echo "MDB_USER=$MDB_USER"  >> $file
    echo "export MDB_USER"  >> $file
    echo ""  >> $file
    MDB_USRPWD=`$MOIADIR/bin/MStrEnc -e ${MDB_PWD}|cut -d" " -f2|cut -d"[" -f2|cut -d"]" -f1`
    echo "MDB_USRPWD=$MDB_USRPWD"  >> $file
    echo "export MDB_USRPWD"  >> $file
    echo ""  >> $file

#    echo "MOIATS=$MOIATS"  >> $file
#    echo "export MOIATS"  >> $file

    echo ""  >> $file
    echo "MOIA_PNODE_NAME=$PNODE_NAME"  >> $file
    echo "export MOIA_PNODE_NAME"  >> $file
    echo ""  >> $file
    echo "MOIA_EVT_PORT=$EVT_PORT"  >> $file
    echo "export MOIA_EVT_PORT"  >> $file
    echo ""  >> $file
    echo "TEMP_AREA_DIR=$MOIADIR/tmp"  >> $file
    echo "export TEMP_AREA_DIR"  >> $file
    echo ""  >> $file
    echo "#--------------------- MOIA PUBLIC END -----------------------# " >>$file

    cat $MOIADIR/env/.org_moia.env >> $file

    cd $MOIADIR
    echo "MOIA_HOME=\${PWD}"  > setenv
    echo "export MOIA_HOME" >> setenv

    echo "" >> setenv
    echo "export PS1='\${LOGNAME}@\${PWD}> '" >> setenv
    echo "set -o vi" >> setenv

    echo "" >> setenv
    echo "alias lf='ls -F'" >> setenv
    echo "alias ll='ls -l'" >> setenv
    echo "alias rm='rm -i'" >> setenv

    echo "" >> setenv
    echo ". \${MOIA_HOME}/env/moia.env" >> setenv

    #
    cd $MOIADIR
    . ./env/moia.env >>/dev/null 2>&1

    if test $? -ne 0;then
        echo "     ERROR: moia.env exec incorrect!" | tee -a $instlog
        exit 1
    fi
}


##########################################################################
# install_moia_env - Handles install moia env ,create moia.env #
##########################################################################
install_agt_env()
{
    # Copy moia environment file
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Create agent environment file ..." | tee -a $instlog
    echo | tee -a $instlog

    sleep 1

    file=$MOIADIR/env/moia.env
    echo "#--------------------- MOIA PUBLIC BEGIN -----------------------# " >$file
    echo "MOIADIR=$MOIADIR" >> $file
    echo "export MOIADIR"  >> $file
    echo ""  >> $file
    echo "MOIAVER=$MOIAVER"  >> $file
    echo "export MOIAVER"  >> $file
    echo ""  >> $file
    echo "OBJECT_MODE=$OBJMODE_IN"  >> $file
    echo "export OBJECT_MODE"  >> $file
    echo ""  >> $file
    echo "INSTMODE=AGT"  >> $file
    echo "export INSTMODE"  >> $file
    echo ""  >> $file
    echo "DSHOME=$DSHOME"  >> $file
    echo "export DSHOME"  >> $file
    echo ""  >> $file
    echo "MOIA_PNODE_NAME=$PNODE_NAME"  >> $file
    echo "export MOIA_PNODE_NAME"  >> $file
    echo ""  >> $file
    echo "MOIA_CLM_PORT=$CLM_PORT"  >> $file
    echo "export MOIA_CLM_PORT"  >> $file
    echo ""  >> $file
    echo "TEMP_AREA_DIR=$MOIADIR/tmp"  >> $file
    echo "export TEMP_AREA_DIR"  >> $file
    echo ""  >> $file
    echo "#--------------------- MOIA PUBLIC END -----------------------# " >>$file

    cat $MOIADIR/env/.org_moia.env >> $file

    cd $MOIADIR
    echo "MOIA_HOME=\${PWD}"  > setenv
    echo "export MOIA_HOME" >> setenv

    echo "" >> setenv
    echo "export PS1='\${LOGNAME}@\${PWD}> '" >> setenv
    echo "set -o vi" >> setenv

    echo "" >> setenv
    echo "alias lf='ls -F'" >> setenv
    echo "alias ll='ls -l'" >> setenv
    echo "alias rm='rm -i'" >> setenv

    echo "" >> setenv
    echo ". \${MOIA_HOME}/env/moia.env" >> setenv

    #
    DBTYPE=""
    export DBTYPE
    cd $MOIADIR
    . ./env/moia.env  >>/dev/null 2>&1

    if test $? -ne 0;then
        echo "     ERROR: moia.env exec incorrect!" | tee -a $instlog
        exit 1
    fi
}

##########################################################################
# cre_db_table - create the tables for moia                              #
##########################################################################
cre_db_table()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Create tables for moia server ..."  | tee -a $instlog
    echo | tee -a $instlog

    if test "X$SERVER_NODE" = "XD";then
        return 0
    fi

    if test ! -f "$MOIADIR/init/server/moia_srv_create.sql"
    then
        echo "     ERROR: $MOIADIR/init/server/moia_srv_create.sql not exist,do exit" | tee -a $instlog
        exit 1
    fi

    if test "X$DBTYPE_IN" = "XORACLE";then
        sh ${MOIADIR}/init/server/moia_srv_create.sql | tee -a $instlog | grep "created"
    else
        type stdbuf
        if test $? -ne 0 
        then 
            sh ${MOIADIR}/init/server/moia_srv_create.sql >> $instlog
        else
            sh ${MOIADIR}/init/server/moia_srv_create.sql | tee -a $instlog | stdbuf -oL grep "CREATE" |stdbuf -oL sed -e 's/.*=>//g' |sed -e 's/(.*//g'
        fi
    fi

    if test $? -ne 0 
    then
        echo "     ERROR: Moia server db create failed!" | tee -a $instlog
        exit 1
    fi
    look_for="Database parameter tables(Server) create successfully!!"
    called_from="Moia create server tables"
   # wait_screen "$look_for" "$called_from"

}

##########################################################################
# init_server_para - initialize Moia paramter database tables            #
##########################################################################
init_server_para()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Initialize server paramter tables for moia ..." | tee -a $instlog
    echo | tee -a $instlog
    echo | tee -a $instlog


    if test "X$SERVER_NODE" = "XD";then
        init_server2_para
        return 0
    fi

    if test ! -f "$MOIADIR/init/server/moia_server_init.sh"
    then
        echo "     ERROR: $MOIADIR/init/server/moia_server_init.sh not exist!" | tee -a $instlog
        exit 1
    fi
    cd $MOIADIR/init/server
    sh moia_server_init.sh $PNODE_NAME $os_hostip $EVT_PORT $CMD_PORT $UDP_PORT $TCP_PORT $CLM_PORT $LSNR_PORT >> $instlog 2>&1 
    if test $? -ne 0 
    then
        echo "     ERROR: Moia server paramters init failed!" | tee -a $instlog
        exit 1
    fi
    look_for="Parameters(server) initialize successfully!!"
    called_from="Initialize server parameters"
  #  wait_screen "$look_for" "$called_from"
}

init_server2_para()
{
    pnode_id=`Muuidgen`
    pinfo="insert into t02_pnode_info values ('$pnode_id','$PNODE_NAME','$HOSTNAME','','1','$os_hostip','$EVT_PORT','$CMD_PORT','$UDP_PORT','$TCP_PORT','$CLM_PORT','$LSNR_PORT','2000','100','100','100','','','','$MOIADIR/log','0','0','','')"
    pstat="insert into t02_pnode_stat values ('$pnode_id','0','0','0','0','0','0','2000','0','0','0','0','','')"
    pdisk="insert into t02_pnode_resinfo values ('$pnode_id','disk','/Datasets','\"\"','','0','0','','')"
    pscra="insert into t02_pnode_resinfo values ('$pnode_id','scratchdisk','/Scratch','\"\"','','0','0','','')"
    
    echo $pinfo
    echo $pstat
    echo $pdisk
    echo $pscra

    if test X$DBTYPE_IN = "XORACLE";then

sqlplus -S ${ORAUSERID} << EOF  >> $instlog 2>&1
WHENEVER SQLERROR EXIT SQL.SQLCODE
$pinfo;
$pstat;
$pdisk;
$pscra;
commit;
quit;
EOF
        if test $? -ne 0 
        then
            echo "     ERROR: Moia server paramters init failed!" | tee -a $instlog
            exit 1
        fi

    else
        db2 connect to ${DB2USERID};
        db2 +c $pinfo;
        if test $? -ne 0;then
            echo "     ERROR: failed exec sql:$pinfo!" | tee -a $instlog
            db2 rollback
            exit 1
        fi
        db2 +c $pstat;
        if test $? -ne 0;then
            echo "     ERROR: failed exec sql:$pinfo!" | tee -a $instlog
            db2 rollback
            exit 1
        fi
        db2 +c $pdisk;
        if test $? -ne 0;then
            echo "     ERROR: failed exec sql:$pinfo!" | tee -a $instlog
            db2 rollback
            exit 1
        fi
        db2 +c $pscra;
        if test $? -ne 0;then
            echo "     ERROR: failed exec sql:$pinfo!" | tee -a $instlog
            db2 rollback
            exit 1
        fi
        db2 commit

    fi
}

##########################################################################
# init_agt_para - initialize Moia paramter database tables            #
##########################################################################
init_agt_para()
{
    sleep 1

    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Initialize agent paramter for moia ..." | tee -a $instlog
    echo | tee -a $instlog
    echo | tee -a $instlog


AGT_PND_ID=`Muuidgen`
AGT_PND_NAME=$PNODE_NAME
AGT_HOSTNAME=`hostname`
AGT_PND_IP=$os_hostip


AGT_EVT_PORT=$EVT_PORT
AGT_CMD_PORT=$CMD_PORT
AGT_UDP_PORT=$UDP_PORT
AGT_TCP_PORT=$TCP_PORT
AGT_CLM_PORT=$CLM_PORT
AGT_LSNR_PORT=$LSNR_PORT
LOG_PATH=$MOIADIR/log

echo "$AGT_PND_ID|$AGT_PND_NAME|$AGT_HOSTNAME|agent|0|$AGT_PND_IP|$AGT_EVT_PORT|$AGT_CMD_PORT|$AGT_UDP_PORT|$AGT_TCP_PORT|$AGT_CLM_PORT|$AGT_LSNR_PORT|2000|100|100|100||||$LOG_PATH|0|0|null|null"  > $MOIADIR/etc/pnode_info.cfg
}

##########################################################################
# moia started                                                           #
##########################################################################
cmd_srv_start()
{

    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     Moia Control service being startup ..." | tee -a $instlog
    echo | tee -a $instlog
    echo | tee -a $instlog


    if test "X$zoo_start" = "X1";then
        $MOIADIR/zookeeper/bin/zkServer.sh start
    fi

    MCMD="${MOIADIR}/bin/MCmdSrv"
    if test ! -f $MCMD
    then
        echo "ERROR: ${MCMD} not exist!"  | tee -a $instlog
        exit 1
    fi

    cd ${MOIADIR}/bin
    #MCmdSrv
    MSrvAdm -t


}

##########################################################################
# moia started                                                           #
##########################################################################
agent_start()
{

    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog
    echo "     MClmAgt service being startup ..." | tee -a $instlog
    echo | tee -a $instlog
    echo | tee -a $instlog

    cd ${MOIADIR}/bin
    MClmAgt
    if test  $? -ne 0
    then
        echo "     ERROR: MClmAgt start up failed!" | tee -a $instlog
        exit 1
    fi

}

##########################################################################
# register pnode information                                              #
##########################################################################
reg_pnode_info()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog

    echo "     Register agent pnode infomation ..." | tee -a $instlog

    DSSERVER=`echo $DSHOME|sed -e 's/\/DSEngine//g'`
    cmd_id=10001
    cmd_str="$AGT_PND_ID|$AGT_PND_NAME|$AGT_HOSTNAME|$AGT_PND_IP|$AGT_EVT_PORT|$AGT_CMD_PORT|$AGT_UDP_PORT|$AGT_TCP_PORT|$AGT_CLM_PORT|$AGT_LSNR_PORT|$LOG_PATH|$DSSERVER"

    MInstAgt $SRV_IP $SRV_PORT $cmd_id "$cmd_str"

    if test $? -ne 0;then
        echo "ERROR: Register agent pnode infomation failed!"  | tee -a $instlog
        exit 1
    fi

    AUTH_USER=`cat $MOIADIR/env/moia.env|grep AUTH_USER`
    export AUTH_USER

}


check_port()
{
    valid_flag=`echo $1 | grep "[^0-9]"`
    if [ "X$valid_flag" != "X" -o "X$1" = "X" ]
    then
        exit
    fi

    if [ $1 -lt 1 -o  $1 -gt 65535 ]
    then
        echo "ERROR: The port must be a value between 1 and 65536!"
        exit 
    fi

    os_name=`uname -s|sed -e 's/-//g'`
    case $os_name in
        Linux)
            valid_flag=`netstat -an | grep -v grep | grep ':$1'`
            ;;
        AIX)
            valid_flag=`netstat -an | grep -v grep | grep '\*\.$1'`
            ;;
        HP-UX)
            valid_flag=`netstat -an | grep -v grep | grep '\*\.$1'`
            ;;
        SunOS)
            valid_flag=`netstat -an | grep -v grep | grep '\*\.$1'`
            ;;
        *)
            echo "ERROR: MOIA not support the $os_name"
            ;;
    esac

    if [ "X$valid_flag" != "X" ]
    then
        echo "ERROR: The port[$1] you input is already used! "
        exit
    fi
}

check_ip_addr()
{
    ping -c 1 $1
    if [ $? -ne 0 ] ;then
       echo "ERROR: Can not connect to $1"
       exit 
    fi
    return 
    valid_flag=`echo $1 | grep -c '^[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}$'`
    if [ $valid_flag -eq 0 ]
    then
        return 1
    fi

    for ip_fld in `echo $1 | awk -F. '{print $1, $2, $3, $4}'`
    do
        if [ $ip_fld -ge 0 -a $ip_fld -le 255 ]
        then
            continue
        else
            return 1
        fi
    done
}


chk_inst_ok()
{
if test X$INSTMODE = "X1"
then
  if test X$DBHOME = "X";then
    echo "ERROR: DBHOME is NULL!"
    exit
  elif test ! -d $DBHOME;then
    echo "ERROR: DBHOME=[$DBHOME] not exist!"
    exit
  fi

  if test X$MOIA_DBS = "X";then
    echo "ERROR: MOIA_DBS is NULL!"
    exit
  fi

  if test X$MDB_USER = "X";then
    echo "ERROR: MDB_USER is NULL!"
    exit
  fi

  if test X$MDB_PWD = "X";then
    echo "ERROR: MDB_PWD is NULL!"
    exit
  fi

elif test X$INSTMODE = "X2"
then
  if test X$DSHOME != "X";then
    if test ! -d $DSHOME;then
      echo "ERROR: DSHOME=[$DSHOME] not exist!"
      exit
    fi
  fi
  if test X$SRV_IP = "X";then
    echo "ERROR: SRV_IP is NULL!"
    exit
  else
    check_ip_addr $SRV_IP
  fi

  if test X$SRV_PORT = "X";then
    echo "ERROR: SRV_PORT is NULL!"
    exit
  else
    check_port $SRV_PORT
  fi

else
  echo "ERROR: INSTMODE=$INSTMODE set error!"
  exit
fi


if test X$PNODE_NAME = "X";then
  echo "ERROR: PNODE_NAME is NULL!"
  exit
fi

if test X$EVT_PORT = "X";then
  echo "ERROR: EVT_PORT is NULL!"
  exit
else
  check_port $EVT_PORT
  if test $? -ne 0;then
     echo "ERROR: EVT_PORT=[$EVT_PORT] set error!"
     exit
  fi
fi

if test X$CMD_PORT = "X";then
  echo "ERROR: CMD_PORT is NULL!"
  exit
else
  check_port $CMD_PORT
  if test $? -ne 0;then
     echo "ERROR: CMD_PORT=[$CMD_PORT] set error!"
     exit
  fi
fi

if test X$UDP_PORT = "X";then
  echo "ERROR: UDP_PORT is NULL!"
  exit
else
  check_port $UDP_PORT
  if test $? -ne 0;then
     echo "ERROR: UDP_PORT=[$UDP_PORT] set error!"
     exit
  fi
fi

if test X$TCP_PORT = "X";then
  echo "ERROR: TCP_PORT is NULL!"
  exit
else
  check_port $TCP_PORT
  if test $? -ne 0;then
     echo "ERROR: TCP_PORT=[$TCP_PORT] set error!"
     exit
  fi
fi

if test X$CLM_PORT = "X";then
  echo "ERROR: CLM_PORT is NULL!"
  exit
else
  check_port $CLM_PORT
  if test $? -ne 0;then
     echo "ERROR: CLM_PORT=[$CLM_PORT] set error!"
     exit
  fi
fi

if test X$LSNR_PORT = "X";then
  echo "ERROR: LSNR_PORT is NULL!"
  exit
else
  check_port $LSNR_PORT
  if test $? -ne 0;then
     echo "ERROR: LSNR_PORT=[$LSNR_PORT] set error!"
     exit
  fi
fi

if test X$INSTMODE = "X1";then
    echo " Your will install a master node:" | tee -a $instlog
    echo "        database home: $DBHOME"    | tee -a $instlog
    echo "            database : $MOIA_DBS"    | tee -a $instlog
    echo "        database user: $MDB_USER"    | tee -a $instlog
    echo "          pnode name : $PNODE_NAME"    | tee -a $instlog
    echo "          event port : $EVT_PORT"    | tee -a $instlog
    echo "        command port : $CMD_PORT"    | tee -a $instlog
elif test X$INSTMODE = "X2";then
    echo " Your will install an agent node:"    | tee -a $instlog
    echo "      server node ip : $SRV_IP"    | tee -a $instlog
    echo " server lisener port : $SRV_PORT"    | tee -a $instlog
  if test X$DSHOME != "X";then
    echo "       Datastage home: $DSHOME"    | tee -a $instlog
  fi
    echo "          pnode name : $PNODE_NAME"    | tee -a $instlog
    echo "         cluser port : $CLM_PORT"    | tee -a $instlog
else
    echo " Not suport the instmode:$INSTMODE"    | tee -a $instlog
    exit
fi
    echo " Please make sure you configure information"    | tee -a $instlog
    continue_info

}

load_default_license()
{
    while [ 1 = 1 ]
    do
        echo
        echo $MINUSN "License file full path:" $SLASHC
        read answer
        if [ -f $answer ];then
            file=$answer
            break
        else
            echo "License file not exist."
        fi
    done

    product_name=`cat $file|grep "Product Name" |sed -e 's/ //g'|awk -F':' '{print $2}'`
    product_ver=`cat $file|grep "Product Version" |sed -e 's/ //g'|awk -F':' '{print $2}'`
    authorize=`cat $file|grep "Authorize To" |sed -e 's/ //g'|awk -F':' '{print $2}'`
    license_type=`cat $file|grep "License Type" |sed -e 's/ //g'|awk -F':' '{print $2}'`
    max_pnodes=`cat $file|grep "Max Pnodes" |sed -e 's/ //g'|awk -F':' '{print $2}'`
    expire_date=`cat $file|grep "Expire Date" |sed -e 's/ //g'|awk -F':' '{print $2}'`
    license=`cat $file|grep "License  " |sed -e 's/ //g'|awk -F':' '{print $2}'`

    today=`date +%Y%m%d`
    last_modify=`date +"%Y/%m/%d %H:%M:%S"`
    sql="insert into t02_sms_license_mng values('$product_name','$product_ver','$authorize','$license_type','$max_pnodes','$expire_date','$license',0,0,'$today','$last_modify')"

if test X$DBTYPE_IN = "XORACLE";then

CONNMSG=`sqlplus -S ${ORAUSERID} << EOF  >> $instlog 2>&1
SET ECHO OFF NEWP 0 SPA 0 PAGES 0 FEED OFF HEAD OFF TRIMS ON
SET HEAD OFF
WHENEVER SQLERROR EXIT SQL.SQLCODE
$sql;
quit;
EOF`

    if test $? -ne 0
    then
        echo "     ERROR: License register failed!" | tee -a $instlog
        exit 1
    fi
else
    db2 connect to ${DB2USERID} >>$instlog 2>&1
    db2 $sql
    if test $? -ne 0
    then
        echo "     ERROR: License register failed!" | tee -a $instlog
        exit 1
    fi
    db2 commit
fi

}

register_license()
{
    if test "X$SERVER_NODE" = "XD";then
        return 0
    fi

    while [ 1 = 1 ]
    do
        echo
        echo $MINUSN "License registerd. F - license file path; I - input license; D or ENTER - default license(2 nodes & 100 jobs): " $SLASHC
        read answer
        if [ "X${answer}" = "XF" -o "X${answer}" = "Xf" ]
        then
            load_default_license 
            break 
        elif [ "X${answer}" = "XI" -o "X${answer}" = "Xi" ]
        then
            MLicMng 
            if test $? -ne 0
            then
                echo "ERROR: License configuration failed!" >> $instlog
                exit 1
            fi
            echo "License configuration is finished!" >> $instlog
            break
        elif [ "X${answer}" = "X" -o "X${answer}" = "XD" -o "X${answer}" = "Xd" ]
        then
            MLicMng -t
            if test $? -ne 0
            then
                echo "ERROR: License configuration failed!" >> $instlog
                exit 1
            fi
            echo "License configuration is finished!" >> $instlog
            break
        fi
    done

}

zoo_config_set()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog

    echo "     Set zookeeper config parameters ..." | tee -a $instlog

    confile=$MOIADIR/install.srv

    if test "X$SERVER_NODE" = "XD";then
        if test "X$ZOOKEEPER_INST" != "X1" ;then
            echo " ERROR:  Double active server must be set ZOOKEEPER_INST=1" | tee -a $instlog
            exit
        fi
        sed -i "s/^G_ZOO_USED.*/G_ZOO_USED=1/g" $MOIADIR/etc/MOIA_ADT.cfg
        sed -i "s/^ZOOK_HOST.*/ZOOK_HOST=$ZOOKEEPER_SERVER/g" $MOIADIR/etc/MOIA_ADT.cfg
    else
        if test "X$ZOOKEEPER_INST" = "X0" ;then
            sed -i "s/^G_ZOO_USED.*/G_ZOO_USED=0/g" $MOIADIR/etc/MOIA_ADT.cfg
        elif test "X$ZOOKEEPER_INST" = "X1" ;then
            sed -i "s/^G_ZOO_USED.*/G_ZOO_USED=1/g" $MOIADIR/etc/MOIA_ADT.cfg
            sed -i "s/^ZOOK_HOST.*/ZOOK_HOST=$ZOOKEEPER_SERVER/g" $MOIADIR/etc/MOIA_ADT.cfg
        elif test "X$ZOOKEEPER_INST" = "X2" ;then
            sed -i "s/^G_ZOO_USED.*/G_ZOO_USED=1/g" $MOIADIR/etc/MOIA_ADT.cfg
            zoo_host=$os_hostip:$clientPort
            sed -i "s/^ZOOK_HOST.*/ZOOK_HOST=$zoo_host/g" $MOIADIR/etc/MOIA_ADT.cfg
            zoo_param_set
            zoo_start=1
        fi
    fi

}

zoo_param_set()
{
     sed -i "/^server/d" $MOIADIR/zookeeper/conf/zoo.cfg
     grep '^server' $MOIADIR/install.zoo >> $MOIADIR/zookeeper/conf/zoo.cfg
     sed -i "s/^clientPort.*/clientPort=$clientPort/g" $MOIADIR/zookeeper/conf/zoo.cfg
     data_dir=$MOIADIR/zookeeper/data
     sed -i "s#^dataDir.*#dataDir=$data_dir#g" $MOIADIR/zookeeper/conf/zoo.cfg
     log_dir=$MOIADIR/zookeeper/log
     sed -i "s#^zookeeper\.log\.dir.*#zookeeper.log.dir=$log_dir#g" $MOIADIR/zookeeper/conf/log4j.properties 
     sed -i "s#^zookeeper\.tracelog\.dir.*#zookeeper.tracelog.dir=$log_dir#g" $MOIADIR/zookeeper/conf/log4j.properties 
     echo "1" > $MOIADIR/zookeeper/data/myid
}

zoo_host_set()
{
    while [ 1 = 1 ]
    do
        echo
        echo $MINUSN "Please input zookeeper server address like 168.16.5.5:2188 :" $SLASHC
        read host 
        echo $MINUSN "Please Confirm your input [$host]: Y - yes, R - retry" $SLASHC
        read answer
        if [ "X${answer}" = "Xy" -o "X${answer}" = "XY" ]
        then
            set -i "s/^G_ZOO_USED.*/G_ZOO_USED=1/g" $MOIADIR/etc/MOIA_ADT.cfg
            set -i "s/^ZOOK_HOST.*/ZOOK_HOST=$host/g" $MOIADIR/etc/MOIA_ADT.cfg
            break
        fi
        if [ "X${answer}" = "Xr" -o "X${answer}" = "XR" ]
        then
            continue
        fi
        if [ "X${answer}" = "Xq" -o "X${answer}" = "XQ" ]
        then
            exit
        fi
    done
}

# ѡΰװserverڵ㻹ǰװ˫ڵ
# װ˫ڵҪ֤ڵϢ
#
#
choise_server_node()
{
    clear_screen

    echo >> $instlog
    echo "     =================================================================" | tee -a $instlog
    echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
    echo "     =================================================================" | tee -a $instlog
    echo | tee -a $instlog

    echo "     Choise install server pnode type ..." | tee -a $instlog

    while [ 1 = 1 ]
    do
        echo
        echo $MINUSN "Install a new server or Distribute server: N - new server; D - Distribute server: " $SLASHC
        read answer

        retry=0 
        while [ 1 = 1 ]
        do
            echo $MINUSN "You chose [$answer], Please confirm your input: Y/Enter - Yes, Q - Quit, R retry: " $SLASHC
            read choise
         
            if [ "X$choise" = "XR" -o "X$choise" = "Xr" ];then
                retry=1 
                break
            elif [ "X$choise" = "X" -o "X$choise" = "Xy" -o "X$choise" = "XY" ];then
                retry=0 
                break
            elif [ "X$choise" = "Xq" -o "X$choise" = "XQ" ];then
                exit 
            else
                continue
            fi
        done
        if [ "X$retry" = "X1" ];then
             continue
        fi

        if [ "X${answer}" = "Xn" -o "X${answer}" = "XN" ]
        then
            SERVER_NODE=N
            break 
        fi
        if [ "X${answer}" = "Xd" -o "X${answer}" = "XD" ]
        then
            #check server node number and server node name
            check_double_node
            SERVER_NODE=D
            break
        fi
    done
}

check_double_node()
{

if test X$DBTYPE_IN = "XORACLE";then

pnode_str=`sqlplus -S ${ORAUSERID}<< ! 
SET ECHO OFF NEWP 0 SPA 0 PAGES 0 FEED OFF HEAD OFF TRIMS ON
SET HEAD OFF
WHENEVER SQLERROR EXIT SQL.SQLCODE
select count(*) from t02_pnode_info where pnode_role = '1';
quit;
!`

    if test $? -ne 0
    then
        echo "ERROR: Select t02_pnode_info failed!" | tee -a $instlog
        exit 1
    fi
    pnode_num=`echo $pnode_str|sed 's/ .*//g'`

pnode_str=`sqlplus -S ${ORAUSERID}<< !
SET ECHO OFF NEWP 0 SPA 0 PAGES 0 FEED OFF HEAD OFF TRIMS ON
SET HEAD OFF
WHENEVER SQLERROR EXIT SQL.SQLCODE
select count(*) from t02_pnode_info where pnode_name = '$PNODE_NAME';
quit;
!`
    if test $? -ne 0
    then
        echo "ERROR: Select t02_pnode_info failed!" >> $instlog
        exit 1
    fi
    pnode_flag=`echo $pnode_str|sed 's/ .*//g'`

else
    db2 connect to $DB2USERID
    pnode_str=`db2 "select count(*) from t02_pnode_info where pnode_role = '1'"`
    pnode_num=`echo ${pnode_str}|sed 's/.*- *//g'|sed 's/ .*//g'`
    if test $? -ne 0
    then
        echo "ERROR: Select t02_pnode_info failed!" | tee -a $instlog 
        exit 1
    fi
    pnode_str=`db2 "select count(*) from t02_pnode_info where pnode_name = '$PNODE_NAME'"`
    pnode_flag=`echo ${pnode_str}|sed 's/.*- *//g'|sed 's/ .*//g'`
    if test $? -ne 0
    then
        echo "ERROR: Select t02_pnode_info failed!" | tee -a $instlog
        exit 1
    fi
fi
    if test "X$pnode_num" = "X0";then
        echo ""
        echo "     ERROR: You must install a master server pnode!" | tee -a $instlog
        exit 1
    fi
    if (($pnode_flag >= 1));then
        echo ""
        echo "     ERROR: System has allready install pnode [$PNODE_NAME]!" | tee -a $instlog
        exit 1
    fi
}

usage()
{
    echo ""
    echo "$0: [-srv|-agt|-make]"
    echo " -srv : install server node. Use install.srv config file."
    echo " -agt : install agent node. Use install.agt config file."
    echo "-make : make agent source file."
    echo ""
    exit
}

################################################################################
## main
echo_machine

ISMAKE=0
SERVER_NODE=N
zoo_start=0
if test "X$1" = "X-srv";then
    CFGFILE=install.srv
    if test ! -f ${CFGFILE}
    then
        echo
        echo "ERROR: ${CFGFILE} is missed!"
        exit 1;
    fi
    . ./install.srv >/dev/null 2>&1
    UDP_PORT=57503
    TCP_PORT=57504
    CLM_PORT=57505
    LSNR_PORT=57500
    INSTMODE=1
#check install.cfg paramters is ok
    chk_inst_ok
elif test "X$1" = "X-agt";then
    CFGFILE=install.agt
    if test ! -f ${CFGFILE}
    then
        echo
        echo "ERROR: ${CFGFILE} is missed!"
        exit 1;
    fi
    . ./install.agt
    EVT_PORT=57501
    CMD_PORT=57502
    UDP_PORT=57503
    TCP_PORT=57504
    LSNR_PORT=57500
    INSTMODE=2
#check install.cfg paramters is ok
    chk_inst_ok
elif test "X$1" = "X-make";then
    ISMAKE=1
    inst_make_env
    echo 
    echo " Make source file OK! Get the install package, use the process:product/moia_agt_prd.sh!"
    exit
else
    usage
fi


mkdir -p $MOIADIR/data
# agentδʱҪ  MOIA_RELEASEļԼbinļٰװ
### GET RELEASE INFORMATION ###
cp $MOIADIR/etc/MOIA_ADT.cfg.tmp $MOIADIR/etc/MOIA_ADT.cfg
cp -rf $MOIADIR/zookeeper.tmp $MOIADIR/zookeeper

SRVFILE=$MOIADIR/etc/MOIA_RELEASE
if test "X$INSTMODE" = "X2" && test ! -f ${SRVFILE} 
then
  inst_make_env
  if [ $? -ne 0 ];then
      echo "ERROR: install make fialed!"
      exit 1
  fi
elif test "X$INSTMODE" = "X1" && test ! -f ${SRVFILE}
then
  echo "ERROR: The MOIA_RELEASE file [$SRVFILE] not exsit!"
  exit 1
fi

MOIAVER=`cat ${SRVFILE}|grep "^MOIAVER"|cut -d'=' -f2`
OS_IN=`cat ${SRVFILE}|grep "^OS="|cut -d'=' -f2`
OSVER_IN=`cat ${SRVFILE}|grep "^OSVER="|cut -d'=' -f2`
OBJMODE_IN=`cat ${SRVFILE}|grep "^OBJECT_MODE"|cut -d'=' -f2`
DBTYPE_IN=`cat ${SRVFILE}|grep "^DBTYPE"|cut -d'=' -f2`
DBVER_IN=`cat ${SRVFILE}|grep "^DBVER"|cut -d'=' -f2`
OBJECT_MODE=$OBJMODE_IN

if test "X${DBTYPE_IN}" = "XORACLE";
then
    export ORACLE_HOME=$DBHOME
else
    export INSTHOME=$DBHOME
fi

if test "X$MOIATS" = "X" ;then
    export MOIATS=
else
    if test "X$DBTYPE_IN" = "XORACLE" ;then
        export MOIATS="tablespace $MOIATS"
    else
        export MOIATS="in $MOIATS"
    fi
fi

# ϵͳͰװreleaseǷƥ
check_platform

#-------------------- install server node ----------------------#
if test X$INSTMODE = "X1";then

#create moia.env & setenv 
install_srv_env

#check the database connect and set lib path
check_db_env

#double server node set
choise_server_node

#double server node set
zoo_config_set

#create table for Moia server
cre_db_table

#if db2, binding files 
db2_bnd_file

#init server parameters
init_server_para

#register the moia license 
register_license

#Moia listenner start up
cmd_srv_start

#-------------------- install agent node ----------------------#
elif test X$INSTMODE = "X2";then

#create moia.env & setenv 
install_agt_env

#check datastage lib path
check_etl_env

#init agent parameters
init_agt_para

#register pnode information
reg_pnode_info

#Moia listenner start up
agent_start

#delete the source file
rm -rf $MOIADIR/.src
rm -rf $MOIADIR/make.env
rm -rf $MOIADIR/etc/make_cfg
rm -rf $MOIADIR/src
rm -rf $MOIADIR/sbin/mcheck
fi


clear_screen
echo >> $instlog
echo "     =================================================================" | tee -a $instlog
echo "               ---------------  N O T I C E  ---------------          " | tee -a $instlog
echo "     =================================================================" | tee -a $instlog
echo | tee -a $instlog
echo "     Moia Control install is finished" | tee -a $instlog
echo "     Quit Install" | tee -a $instlog
echo | tee -a $instlog


