#!/bin/sh
###################################################
# uninstall.sh 
# Only used in server node 
#
# Set variables, check uinstall requirements
# and runs the compiled setup program
#
##############################################################################
#
# Maintenence log - insert most recent change descriptions at top
#
# Date......   Version  Description...........................................
# 2015/06/30   5.02     Moia Control Develop
##############################################################################
umask 0022

unique=`date '+%Y%m%d.%H%M%S'`
uninstlog=$MOIADIR/iMoiaUninstall.log.$unique
uninstlog=/dev/null
tmpfile=tmp_file.$$

cmd_help()
{
    echo ""
    echo " Usage: $0 -g|-p <pnode_name>"
    echo "        -g              use the guide mode to uninstall pnode (All Run nodes). "
    echo "        -p <pnode_name> uninstall pnode for pnode name (Other Schedul nodes). "
    echo ""
    echo " Attention: This program can not uninstall the schedul node!!!  "
    echo ""
    exit 1
}

##########################################################################
# echo_machine - Handles surpressing of automatic newlines when echoing  #
##########################################################################
echo_machine()
{
    if [ "`echo -n ''`" = "" ]
    then
        MINUSN="-n"
        SLASHC=""
    else
        MINUSN=""
        SLASHC='\c'
    fi
}

continue_info()
{
    while [ 1 = 1 ]
    do
        echo
        echo $MINUSN " Q - Quit; C or < cr > to continue: " $SLASHC
        read answer
        if [ "X${answer}" = "XQ" -o "X${answer}" = "Xq" ]
        then
            exit
        fi
        if [ "X${answer}" = "X" -o "X${answer}" = "XC" ]
        then
            echo
            break
        fi
    done
}

get_db_conn()
{
    labstr=moia_uninstall

    if test "X$DBTYPE" = "XORACLE"
    then
        if test "X${ORAUSERID}" = "X" ;then 
             echo "ERROR: Please  activate the environment variables!" | tee -a ${uninstlog}
             exit
        fi 
        DB_CONN_CMD="sqlplus ${ORAUSERID}"
    elif test "X$DBTYPE" = "XDB2" 
    then
        if test "X${DB2USERID}" = "X" ;then 
             echo "ERROR: Please  activate the environment variables!" | tee -a ${uninstlog}
             exit
        fi 
        db2 connect to ${DB2USERID} > /dev/null 2>&1
        export DB2OPTIONS='-st';
        DB_CONN_CMD="db2 -"
    else
        echo "ERROR: Unknow the DBTYPE[&DBTYPE]!" | tee -a ${uninstlog}
        do_exit
    fi
}


list_all_pnode()
{

if test "X$DBTYPE" = "XORACLE"
then
    ora_list_pnode
else
    db2_list_pnode
fi

echo 
echo " All pnode information as folow:"
echo "--------------------------------------------------------------------------"

awk 'BEGIN{printf "NO. PNODE_NAME         PNODE_ID                         IP";printf "\n";
FS="|";RS="\n";OFS=" ";ORS="\n";r=1; }
{
    printf "%-3d %-18s %-32s %-15s\n",r,$1,$2,$3;
    r++;
}' ${tmpfile}

echo "--------------------------------------------------------------------------"
}


db2_list_pnode()
{
db2 - << EOF | \
awk 'BEGIN{wt=0}{\
if( $0 ~/--------/ ){ wt=1; next;} \
if( $0 ~/selected/ ){ wt=0; next;} \
if( wt == 1 && $0 ~/\|/ ) print $0; }' >> ${tmpfile}
SELECT PNODE_NAME|| '|' ||PNODE_ID || '|' || IP_ADDR
  FROM T02_PNODE_INFO
 WHERE PNODE_ROLE = 0;
quit;
EOF
if [ $? -ne 0 ]
then
   cat ${tmpfile} >> ${uninstlog}
   rm -rf ${tmpfile}
   echo "ERROR: Select data failed!" | tee -a ${uninstlog}
   exit 1
fi

}

ora_list_pnode()
{
sqlplus -S ${ORAUSERID}<< EOF >> ${tmpfile}
SET ECHO OFF NEWP 0 SPA 0 PAGES 0 FEED OFF HEAD OFF TRIMS ON
SET HEAD OFF
WHENEVER SQLERROR EXIT SQL.SQLCODE
SELECT PNODE_NAME|| '|' ||PNODE_ID || '|' || IP_ADDR
  FROM T02_PNODE_INFO
 WHERE PNODE_ROLE = 0;
quit;
EOF
if [ $? -ne 0 ]
then
   cat ${tmpfile} >> ${uninstlog}
   rm -rf ${tmpfile}
   echo "ERROR: Select data failed!" | tee -a ${uninstlog}
   exit 1
fi

}

choice_and_del()
{
    row=`cat $tmpfile|wc -l`
    echo 
    echo $MINUSN " Choose one of the NO. to uninstall [ NO. | q/Q - quit ]: " $SLASHC | tee -a ${uninstlog}
    read answer
    
    while [ 1 = 1 ]
    do
        if [ "X$answer" = "Xq" -o "X$answer" = "XQ" ];then
            rm -rf ${tmpfile}
            exit
        fi

        valid_flag=`echo $answer | grep "[^0-9]"`
        if [ "X$valid_flag" != "X" -o "X$answer" = "X" ]
        then
            echo $MINUSN " Choose one of the NO. to uninstall [ NO. | q/Q - quit ]: " $SLASHC | tee -a ${uninstlog}
            read answer
        elif [ $answer -lt 0 -o $answer -gt $row ]
        then
            echo $MINUSN " Choose one of the NO. to uninstall [ NO. | q/Q - quit ]: " $SLASHC | tee -a ${uninstlog}
            read answer
        else
            break
        fi
    done

    pnode_name=`sed -n ${answer}p ${tmpfile} | awk -F '|' '{print $1}'`
    pnode_id=`sed -n ${answer}p ${tmpfile} | awk -F '|' '{print $2}'`
    rm -rf $tmpfile

}


uninst_agent_pnode()
{
IPADDR=$1
PORT=$2
PNODE_NAME=$3
IPADDR2=$4
PORT2=$5

echo 
echo $MINUSN " Uninstall the pnode [$PNODE_NAME] " $SLASHC 
continue_info

MMsgSend -d $IPADDR -p $PORT -s "10002|$PNODE_NAME|"

if [ $? -ne 0 ]
then
    if [ "X$IPADDR2" != "X" -a "X$PORT2" != "X" ];then
        MMsgSend -d $IPADDR2 -p $PORT2 -s "10002|$PNODE_NAME|"
        if [ $? -ne 0 ]
        then
            echo " ERROR: Uninstall the pnode [$PNODE_NAME] failed!" | tee -a ${uninstlog}
            exit 1
        fi
    else
        echo " ERROR: Uninstall the pnode [$PNODE_NAME] failed!" | tee -a ${uninstlog}
        exit 1
    fi
fi

echo 
echo " Uninstall pnode [$PNODE_NAME] successfully !" | tee -a ${uninstlog}
echo

}

uninst_pnode()
{
IPADDR=$1
PORT=$2
PNODE_NAME=$3

echo
echo $MINUSN " Uninstall the pnode [$PNODE_NAME] " $SLASHC
continue_info

MMsgSend -d $IPADDR -p $PORT -s "10002|$PNODE_NAME|"

if [ $? -ne 0 ]
then
    echo " ERROR: Uninstall the pnode [$PNODE_NAME] failed!" | tee -a ${uninstlog}
    exit 1
fi

echo
echo " Uninstall pnode [$PNODE_NAME] successfully !" | tee -a ${uninstlog}
echo

}

get_srv_pnode()
{
    if [ ! -f $MOIADIR/etc/pnode_info.cfg ];then 
        echo "" |tee -a ${uninstlog}
        exit 1
    fi
   
    pnode_info=`awk 'BEGIN{ FS="|";RS="\n";OFS=" ";ORS="\n";r=1; }
{
    if( $5 == 1 ) {
        printf "%s|%s|", $6,$7;
    }
}' $MOIADIR/etc/pnode_info.cfg`

    SRV_IP=`echo $pnode_info|awk -F '|' '{print $1}'`
    SRV_PORT=`echo $pnode_info|awk -F '|' '{print $2}'`
    SRV_IP2=`echo $pnode_info|awk -F '|' '{print $3}'`
    SRV_PORT2=`echo $pnode_info|awk -F '|' '{print $4}'`

}

##################################
##### main ####
echo_machine

###################################
## server

if test X$INSTMODE = XSRV;then

  get_db_conn
  
  if test "X$1" = "X-g"
  then
    list_all_pnode
    choice_and_del
    uninst_pnode $HOSTNAME $MOIA_EVT_PORT $pnode_name
  elif test "X$1" = "X-p"
  then
    if test "X$2" != "X" -a "X$2" != "X${MOIA_PNODE_NAME}"
    then
      uninst_pnode $HOSTNAME $MOIA_EVT_PORT $2
    else
      cmd_help
    fi
  else
    cmd_help
  fi

else
  ###################################
  ## agent
    get_srv_pnode
    uninst_agent_pnode $SRV_IP $SRV_PORT ${MOIA_PNODE_NAME} $SRV_IP2 $SRV_PORT2
fi
